userelaina - Muz
====================================

.. image:: https://img.shields.io/pypi/v/muz.svg
   :target: https://pypi.org/project/muz/

A console music player. 

You can use pip to install packages from the `Python Package Index`_ and other indexes.

* `GitHub page`_
* `Issue tracking`_

.. _Python Package Index: https://pypi.org
.. _GitHub page: https://github.com/userElaina/console-music-player
.. _Issue tracking: https://github.com/userElaina/console-music-player/issues
